gym\_ignition\_environments.tasks
=================================

.. automodule:: gym_ignition_environments.tasks
   :members:
   :undoc-members:
   :show-inheritance:


gym\_ignition\_environments.tasks.cartpole\_continuous\_balancing
-----------------------------------------------------------------

.. automodule:: gym_ignition_environments.tasks.cartpole_continuous_balancing
   :members:
   :undoc-members:
   :show-inheritance:

gym\_ignition\_environments.tasks.cartpole\_continuous\_swingup
---------------------------------------------------------------

.. automodule:: gym_ignition_environments.tasks.cartpole_continuous_swingup
   :members:
   :undoc-members:
   :show-inheritance:

gym\_ignition\_environments.tasks.cartpole\_discrete\_balancing
---------------------------------------------------------------

.. automodule:: gym_ignition_environments.tasks.cartpole_discrete_balancing
   :members:
   :undoc-members:
   :show-inheritance:

gym\_ignition\_environments.tasks.pendulum\_swingup
---------------------------------------------------

.. automodule:: gym_ignition_environments.tasks.pendulum_swingup
   :members:
   :undoc-members:
   :show-inheritance:
